<li class="social-item">
    <div class="facebook-this">
        <a href="https://www.facebook.com/sharer/sharer.php?u={{ share_url }}" target="_blank">
            <span><i class="fa fa-facebook"></i></span>
        </a>
    </div>
</li>
<li class="social-item">
    <div class="tweet-this">
        <a href="https://twitter.com/share?url={{ share_url }}&text={{ entry.title }}" class="meta-act-link meta-tweet" target="_blank">
            <span><i class="fa fa-twitter"></i></span>
        </a>
    </div>
</li>
<li class="social-item">
    <div class="linkedin-this">
        <a class="box-social" href="https://www.linkedin.com/shareArticle?url={{ share_url }}&title={{ entry.title }}&summary={{ entry.search_description }}" target="_blank">
            <span><i class="fa fa-linkedin"></i></span>
        </a>
    </div>
</li>
